@@ -789,8 +789,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
                     return None
                 if not disambiguate:
                     return '.'.join([str(self),cat,'1'])
-                prev = [str(x) for x in self.get_previous_context(window=10)]
-                foll = [str(x) for x in self.get_following_context(window=10)]
+                prev = ' '.join([str(x) for x in self.get_previous_context(window=10)])
+                foll = ' '.join([str(x) for x in self.get_following_context(window=10)])
                 self.Output['Wordnet_sense'] = SEM_PRED.disambiguate_sense(str(self),cat,prev,foll,to_string=True)
                 self.save()
             return self.Output['Wordnet_sense']
